<?php

declare(strict_types=1);

namespace Dedi\SyliusContactPlugin\Entity;

use DateTime;
use Doctrine\ORM\Mapping as ORM;
use Gedmo\Timestampable\Traits\TimestampableEntity;

/**
 * Class ContactFormMessage
 *
 * @ORM\Entity()
 * @ORM\Table(name="dedi_sylius_contact_message")
 */
class ContactFormMessage implements ContactFormMessageInterface
{
    use TimestampableEntity;

    /**
     * @ORM\Column(name="id", type="integer", nullable=false)
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    protected ?int $id;

    /**
     * @ORM\ManyToOne(targetEntity="Dedi\SyliusContactPlugin\Entity\ContactFormSubjectInterface")
     * @ORM\JoinColumn(name="subject_id", referencedColumnName="id")
     */
    protected ContactFormSubjectInterface $subject;

    /**
     * @ORM\Column(name="name", type="string")
     */
    protected ?string $name;

    /**
     * @ORM\Column(name="email", type="string", nullable=false)
     */
    protected ?string $email;

    /**
     * @ORM\Column(name="phone", type="string", nullable=true)
     */
    protected ?string $phone;

    /**
     * @ORM\Column(name="message", type="text", nullable=false)
     */
    protected ?string $message;

    /**
     * @ORM\Column(name="ip", type="string")
     */
    protected ?string $ip;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getSubject(): ContactFormSubjectInterface
    {
        return $this->subject;
    }

    public function setSubject(ContactFormSubjectInterface $subject): self
    {
        $this->subject = $subject;

        return $this;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(?string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getPhone(): ?string
    {
        return $this->phone;
    }

    public function setPhone(?string $phone): self
    {
        $this->phone = $phone;

        return $this;
    }

    public function getMessage(): ?string
    {
        return $this->message;
    }

    public function setMessage(?string $message): self
    {
        $this->message = $message;

        return $this;
    }

    public function getIp(): ?string
    {
        return $this->ip;
    }

    public function setIp(?string $ip): self
    {
        $this->ip = $ip;

        return $this;
    }

    public function getEmail(): ?string
    {
        return $this->email;
    }

    public function setEmail(?string $email): self
    {
        $this->email = $email;

        return $this;
    }

    public function getCreatedAt(): DateTime
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): DateTime
    {
        return $this->updatedAt;
    }
}
