<?php

declare(strict_types=1);

namespace Dedi\SyliusContactPlugin\Entity;

use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Resource\Model\AbstractTranslation;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Class ContactFormSubjectTranslation
 *
 * @ORM\Entity()
 * @ORM\Table(name="dedi_sylius_contact_subject_translation")
 */
class ContactFormSubjectTranslation extends AbstractTranslation implements ContactFormSubjectTranslationInterface
{
    /**
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     * @ORM\Column(name="id", type="integer", nullable=false)
     */
    protected ?int $id;

    /**
     * @ORM\Column(name="label", type="string", nullable=false)
     * @Assert\NotBlank(groups={"default", "sylius"})
     */
    protected ?string $label = null;

    /**
     * @ORM\Column(name="recipient_email", type="string", nullable=false)
     * @Assert\NotBlank(groups={"default", "sylius"})
     * @Assert\Email(groups={"default", "sylius"})
     */
    protected ?string $recipientEmail = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLabel(): ?string
    {
        return $this->label;
    }

    public function setLabel(?string $label): self
    {
        $this->label = $label;

        return $this;
    }

    public function getRecipientEmail(): ?string
    {
        return $this->recipientEmail;
    }

    public function setRecipientEmail(?string $recipientEmail): self
    {
        $this->recipientEmail = $recipientEmail;

        return $this;
    }
}
